(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('prismjs'), require('@angular/common'), require('@angular/core'), require('@angular/common/http'), require('marked'), require('rxjs'), require('rxjs/operators')) :
    typeof define === 'function' && define.amd ? define('@ng-tangram/markdown', ['exports', 'prismjs', '@angular/common', '@angular/core', '@angular/common/http', 'marked', 'rxjs', 'rxjs/operators'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory((global.nt = global.nt || {}, global.nt.markdown = {}), global.Prism, global.ng.common, global.ng.core, global.ng.common.http, global.marked, global.rxjs, global.rxjs.operators));
}(this, (function (exports, prismjs, common, core, http, marked, rxjs, operators) { 'use strict';

    function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

    var marked__default = /*#__PURE__*/_interopDefaultLegacy(marked);

    var NT_MARKDOWN_ENGINE = new core.InjectionToken('nt-markdown-engine');

    var NtMarkdownComponent = /** @class */ (function () {
        function NtMarkdownComponent(_platformId, _markdownEngine, _elementRef) {
            this._platformId = _platformId;
            this._markdownEngine = _markdownEngine;
            this._elementRef = _elementRef;
        }
        Object.defineProperty(NtMarkdownComponent.prototype, "path", {
            get: function () { return this._path; },
            set: function (value) { this._path = value || ''; },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(NtMarkdownComponent.prototype, "data", {
            get: function () { return this._data; },
            set: function (value) { this._data = value; },
            enumerable: false,
            configurable: true
        });
        NtMarkdownComponent.prototype.ngOnChanges = function (changes) {
            var pathChange = changes.path;
            var dataChange = changes.data;
            if (pathChange && !pathChange.firstChange) {
                this._pathChange();
            }
            if (dataChange && !dataChange.firstChange) {
                this._dataChange();
            }
        };
        NtMarkdownComponent.prototype.ngAfterViewInit = function () {
            if (this.path) {
                this._pathChange();
            }
            else {
                this._dataChange();
            }
        };
        NtMarkdownComponent.prototype._dataChange = function () {
            var _this = this;
            if (this.data) {
                this._markdownEngine
                    .compile(this.data)
                    .subscribe(function (markdown) { return _this._setMarkdownHtml(markdown); });
            }
            else {
                this._setMarkdownHtml('');
            }
        };
        NtMarkdownComponent.prototype._pathChange = function () {
            var _this = this;
            if (this.path) {
                this._ext = this.path && this.path.split('.').splice(-1).join();
                this._markdownEngine.getContent(this.path).subscribe(function (content) {
                    content = _this._ext !== 'md' ? ['```', _this._ext + "\n" + content + "\n", '```'].join() : content;
                    _this._markdownEngine.compile(_this._prepare(content)).subscribe(function (markdown) { return _this._setMarkdownHtml(markdown); });
                }, function (error) { return _this._handleError(error); });
            }
        };
        NtMarkdownComponent.prototype._handleError = function (error) {
            return Promise.reject(error.message || error);
        };
        NtMarkdownComponent.prototype._prepare = function (raw) {
            var _this = this;
            if (!raw) {
                return '';
            }
            if (this._ext === 'md' || !this.path) {
                var isCodeBlock_1 = false;
                return raw.split('\n').map(function (line) {
                    if (_this._trimLeft(line).substring(0, 3) === "```") {
                        isCodeBlock_1 = !isCodeBlock_1;
                    }
                    return isCodeBlock_1 ? line : line.trim();
                }).join('\n');
            }
            return raw.replace(/\"/g, '\'');
        };
        NtMarkdownComponent.prototype._postpare = function () {
            if (common.isPlatformBrowser(this._platformId)) {
                prismjs.highlightAll(false);
            }
        };
        NtMarkdownComponent.prototype._setMarkdownHtml = function (markdown) {
            this._elementRef.nativeElement.innerHTML = markdown;
            this._postpare();
        };
        NtMarkdownComponent.prototype._trimLeft = function (line) {
            return line.replace(/^\s+|\s+$/g, '');
        };
        return NtMarkdownComponent;
    }());
    NtMarkdownComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'nt-markdown, [nt-markdown]',
                    template: '',
                    encapsulation: core.ViewEncapsulation.None,
                    host: {
                        class: 'nt-markdown'
                    }
                },] }
    ];
    NtMarkdownComponent.ctorParameters = function () { return [
        { type: Object, decorators: [{ type: core.Inject, args: [core.PLATFORM_ID,] }] },
        { type: undefined, decorators: [{ type: core.Inject, args: [NT_MARKDOWN_ENGINE,] }] },
        { type: core.ElementRef }
    ]; };
    NtMarkdownComponent.propDecorators = {
        path: [{ type: core.Input }],
        data: [{ type: core.Input }]
    };

    var NtMarkdownModule = /** @class */ (function () {
        function NtMarkdownModule() {
        }
        return NtMarkdownModule;
    }());
    NtMarkdownModule.decorators = [
        { type: core.NgModule, args: [{
                    imports: [common.CommonModule],
                    declarations: [NtMarkdownComponent],
                    exports: [NtMarkdownComponent]
                },] }
    ];

    var NT_MARKED_DEFAULT_OPTIONS = {
        gfm: true,
        breaks: false,
        pedantic: false,
        smartLists: true,
        smartypants: false
    };
    var NT_MARKED_OPTIONS = new core.InjectionToken('nt-marked-options');

    var NtMarkedEngine = /** @class */ (function () {
        function NtMarkedEngine(http, options) {
            if (options === void 0) { options = {}; }
            this.http = http;
            this._renderer = new marked__default['default'].Renderer();
            this.extendRenderer();
            this.setMarkedOptions(options);
        }
        Object.defineProperty(NtMarkedEngine.prototype, "renderer", {
            get: function () { return this._renderer; },
            enumerable: false,
            configurable: true
        });
        NtMarkedEngine.prototype.getContent = function (path) {
            return this.http.get(path, { responseType: 'text' }).pipe(operators.catchError(this.handleError));
        };
        NtMarkedEngine.prototype.setMarkedOptions = function (options) {
            options.renderer = this._renderer;
            marked__default['default'].setOptions(options);
        };
        NtMarkedEngine.prototype.compile = function (data) { return rxjs.of(marked__default['default'](data)); };
        NtMarkedEngine.prototype.handleError = function (error) {
            var errMsg;
            if (error instanceof http.HttpResponse) {
                var body = error.body || '';
                var err = body.error || JSON.stringify(body);
                errMsg = error.status + " - " + (error.statusText || '') + " " + err;
            }
            else {
                errMsg = error.message ? error.message : error.toString();
            }
            return rxjs.throwError(errMsg);
        };
        NtMarkedEngine.prototype.extendRenderer = function () {
            this._renderer.heading = function (text, level) {
                text = text.trim();
                return "<h" + level + " id=\"" + text.replace(/\<a[^>]*?\>((.|\n)*?)\<\/a\>/g, '$1').replace(/ +/g, '-') + "\">\n\t\t\t\t\t\t" + text + "\n\t\t\t\t\t</h" + level + ">";
            };
            this._renderer.listitem = function (text) {
                if (/^\s*\[[x ]\]\s*/.test(text)) {
                    var checkedStyle = 'vertical-align: middle; margin: 0 0.2em 0.25em -1.6em; font-size: 16px;';
                    text = text
                        .replace(/^\s*\[ \]\s*/, "<input type=\"checkbox\" style=\"" + checkedStyle + "\" disabled>")
                        .replace(/^\s*\[x\]\s*/, "<input type=\"checkbox\" style=\"" + checkedStyle + "\" checked disabled>");
                    return "<li style=\"list-style: none\">" + text + "</li>";
                }
                else {
                    return "<li>" + text + "</li>";
                }
            };
        };
        return NtMarkedEngine;
    }());
    NtMarkedEngine.decorators = [
        { type: core.Injectable }
    ];
    NtMarkedEngine.ctorParameters = function () { return [
        { type: http.HttpClient },
        { type: undefined, decorators: [{ type: core.Optional }, { type: core.Inject, args: [NT_MARKED_OPTIONS,] }] }
    ]; };

    var ɵ0 = NT_MARKED_DEFAULT_OPTIONS;
    var NtMarkedEngineModule = /** @class */ (function () {
        function NtMarkedEngineModule() {
        }
        return NtMarkedEngineModule;
    }());
    NtMarkedEngineModule.decorators = [
        { type: core.NgModule, args: [{
                    imports: [http.HttpClientModule],
                    providers: [
                        { provide: NT_MARKDOWN_ENGINE, useClass: NtMarkedEngine },
                        { provide: NT_MARKED_OPTIONS, useValue: ɵ0 },
                    ],
                },] }
    ];

    exports.NT_MARKDOWN_ENGINE = NT_MARKDOWN_ENGINE;
    exports.NT_MARKED_DEFAULT_OPTIONS = NT_MARKED_DEFAULT_OPTIONS;
    exports.NT_MARKED_OPTIONS = NT_MARKED_OPTIONS;
    exports.NtMarkdownComponent = NtMarkdownComponent;
    exports.NtMarkdownModule = NtMarkdownModule;
    exports.NtMarkedEngine = NtMarkedEngine;
    exports.NtMarkedEngineModule = NtMarkedEngineModule;
    exports.ɵ0 = ɵ0;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=markdown.umd.js.map
